@@ -1,6 +1,7 @@
 import argparse
 
 from . import _elabftw_interface as elabqr
+from . import _global_defaults as gconf
 from . import _cli_args as cli
 from . import create_qr_sticker as cqs
 
@@ -14,22 +15,26 @@ def get_args_cli():
     parser = cli.add_args_sticker_basic_content(parser)
     parser = cli.add_args_sticker_layout(parser)
     parser = cli.add_output_args(parser)
+    parser = cli.add_args_elab_connection(parser)
     p = parser.parse_args()
     return p
 
 
 def _create_qr_elab_sticker(p):
-    manager = elabqr.initialize()
+    if not p.do_not_verify:
+        verify = gconf.VERIFY
+    manager = elabqr.initialize(url=p.url, token=p.token, verify=verify)
     item = manager.get_item(p.id_no)
-    servname = elabqr._get_domain_name()
-    link = f"https://{servname}/database.php?mode=view&id={p.id_no}"
+    link = f"{p.url}/database.php?mode=view&id={p.id_no}"
     p.data = link
+    print(item['title'])
+    print(item['date'])
     short_desc = f"{item['date']} {item['title']}"
-    print(f"Will create QR sticker for link {link} and title {short_desc}")
-    if p.short_text:
-        short_desc = p.short_text
+    if not p.short_text:
+        p.short_text = short_desc
     if p.no_short_text:
-        short_desc = ""
+        p.short_text = ""
+    print(f"Will create QR sticker for link {link} and label with: {p.short_text}")
     cqs._create_qr_sticker_params(p)
     print(f"Created QR sticker for item {p.id_no} at {p.output}")
 
